﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace howto_delete_files
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Sort the files.
        private void Form1_Load(object sender, EventArgs e)
        {
            txtPath.Text = Application.StartupPath;
            clstFiles.Sorted = true;
        }

        // List the selected files.
        private void btnListFiles_Click(object sender, EventArgs e)
        {
            clstFiles.Items.Clear();
            try
            {
                DirectoryInfo dir_info = new DirectoryInfo(txtPath.Text);
                foreach (FileInfo file_info in dir_info.GetFiles(
                    txtPattern.Text, SearchOption.AllDirectories))
                {
                    int index = clstFiles.Items.Add(file_info.FullName);
                    clstFiles.SetItemChecked(index, true);
                }
                lblNumFiles.Text = clstFiles.Items.Count + " files";
                btnDelete.Enabled = clstFiles.CheckedIndices.Count > 0;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        // Delete the checked files.
        private void btnDelete_Click(object sender, EventArgs e)
        {
            string[] filenames = new string[clstFiles.CheckedItems.Count];
            clstFiles.CheckedItems.CopyTo(filenames, 0);
            foreach (string filename in filenames)
            {
                Console.WriteLine(filename);
                try
                {
                    File.Delete(filename);
                    clstFiles.Items.Remove(filename);
                }
                catch (Exception ex)
                {
                    Console.WriteLine("Error deleting file. " + ex.Message);
                    if (MessageBox.Show("Error deleting file. " + ex.Message +
                        Environment.NewLine + Environment.NewLine +
                        "Continue?", "Continue?",
                        MessageBoxButtons.YesNo, MessageBoxIcon.Question)
                            == DialogResult.No)
                        break;
                }
            }

            lblNumFiles.Text = clstFiles.CheckedItems.Count + " files";
            btnDelete.Enabled = clstFiles.CheckedItems.Count > 0;
        }

        // Disable the Delete button.
        private void txt_TextChanged(object sender, EventArgs e)
        {
            btnDelete.Enabled = false;
        }

        // Enable the Delete button if any item is checked.
        private void clstFiles_ItemCheck(object sender, ItemCheckEventArgs e)
        {
            int num_checked = clstFiles.CheckedItems.Count;
            if (e.NewValue != e.CurrentValue)
            {
                if (e.NewValue == CheckState.Checked) num_checked++;
                else if (e.NewValue == CheckState.Unchecked) num_checked--;
            }

            lblNumFiles.Text = num_checked + " files";
            btnDelete.Enabled = num_checked > 0;
        }
    }
}
